#
# spec file for package easy-rsa
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Stefan Jakobs.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pname   EasyRSA-unix

Name:           easy-rsa
Version:        3.0.6
Release:        lp151.1.1
Summary:        CLI utility to build and manage a PKI CA
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
Url:            https://github.com/OpenVPN/easy-rsa
Source:         https://github.com/OpenVPN/%{name}/releases/download/v%{version}/%{pname}-v%{version}.tgz
Source1:        https://github.com/OpenVPN/%{name}/releases/download/v%{version}/%{pname}-v%{version}.tgz.sig
# https://github.com/OpenVPN/easy-rsa/tree/master/release-keys
Source2:        %{name}.keyring
Patch100:       suse-packaging.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
easy-rsa is a CLI utility to build and manage a Public Key Infrastructure
(PKI). Once the Certificate Authority (CA) is created, you can request and sign
certificates, including sub-CAs, and create Certificate Revokation Lists (CRL).

%prep
#setup -q -n %{pname}-%{version}
%setup -q -n EasyRSA-v%{version}
%patch100

%build

%install
install -dm0755 %{buildroot}/%{_sysconfdir}/%{name}/
install -dm0755 %{buildroot}/%{_sysconfdir}/%{name}/x509-types
install -Dm0644 vars.example %{buildroot}/%{_sysconfdir}/%{name}/
install -Dm0644 openssl-easyrsa.cnf %{buildroot}/%{_sysconfdir}/%{name}/
install -Dm0644 x509-types/* %{buildroot}/%{_sysconfdir}/%{name}/x509-types/
install -Dm0755 easyrsa %{buildroot}/%{_bindir}/easyrsa

%files
%defattr(-,root,root)
%doc ChangeLog README.md README.quickstart.md
%doc doc/*
%if 0%{?sle_version} == 11 || 0%{?sle_version} <= 120400
%doc COPYING.md gpl-2.0.txt
%else
%license COPYING.md gpl-2.0.txt
%endif
%{_bindir}/easyrsa
%config(noreplace) %{_sysconfdir}/%{name}

%changelog
* Tue Feb 12 2019 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- update to 3.0.6 (2019-02-01)
  * Certifcates that are revoked now move to a revoked subdirectory (#63)
  * EasyRSA no longer clobbers non-EASYRSA environment variables (#277)
  * More sane string checking, allowingn for commas in CN (#267)
  * Support for reasonCode in CRL (#280)
  * Better handling for capturing passphrases (#230, others)
  * Improved LibreSSL/MacOS support
  * Adds support to renew certificates up to 30 days before expiration (#286)
  - This changes previous behavior allowing for certificate creation using
    duplicate CNs.
- update and rebase suse-packaging.patch
* Fri Nov 30 2018 chris@computersalat.de
- update to 3.0.5
  * Fix #17 & #58: use AES256 for CA key
  * Also, don't use read -s, use stty -echo
  * Fix broken "nopass" option
  * Add -r to read to stop errors reported by shellcheck (and to behave)
  * remove overzealous quotes around $pkcs_opts (more SC errors)
- update and rebase suse-packaging.patch
  * fix: set_var EASYRSA in vars.example
- fix License
* Sun Jan 28 2018 seroton10@gmail.com
- Upgrade to version 3.0.4
  * Remove use of egrep (#154)
  * Finally(?) fix the subjectAltName issues (really fixes #168)
- Improve RPM description
* Wed Oct 18 2017 astieger@suse.com
- update release tarball instead of git snapshot
- add upstream signing keyring and verify source signature
* Mon Oct 16 2017 seroton10@gmail.com
- Update to version 3.0.3
- Rename easy-rsa-packaging.patch to suse-packaging.patch
- Remove obsolete upstream patches:
  * f174800.patch
  * 29d4dee.patch
  * b93d0a1.patch
  * fb4d8d8.patch
  * b75faa4.patch
  * 6436eaf.patch
  * e9e8e27.patch
  * 534f673.patch
  * d20d2b3.patch
  * 4eac410.patch
  * a138c0d.patch
  * 83a1a21.patch
* Wed Aug 23 2017 seroton10@gmail.com
- Include upstream patches:
  + 4eac410.patch
    Fix string comprehension
  + a138c0d.patch
    Fix incorrect "openssl rand" usage
  + 83a1a21.patch
    Add --copy-ext option
* Fri Jul 28 2017 seroton10@gmail.com
- Include upstream patches:
  + d20d2b3.patch
    Update docs and examples to fit changes in 534f673
- Adapted easy-rsa-packaging.patch to work with upstream patch
* Mon Jul 24 2017 seroton10@gmail.com
- Include upstream patches:
  + 534f673.patch
    Make $PWD/pki the default PKI location
- Adapted easy-rsa-packaging.patch to work with upstream patch
- Treat /etc/easy-rsa as public default config, no default vars
* Tue Jul 18 2017 seroton10@gmail.com
- Include upstream patches:
  + 6436eaf.patch
    Add CN as SAN (if none requested) on server certs by default
  + e9e8e27.patch
    Moved @ValdikSS's serial randomization to sign_req
* Mon Jun  5 2017 seroton10@gmail.com
- Undo removal of .md suffix on markdown documentation
* Sat May 27 2017 bruno@ioda-net.ch
- Add special %%if for SLE11 as patch tool can't rename files.
- Include upstream patches
  + f174800.patch
    Generate random serial number for all certificates
  + 29d4dee.patch
    Fixes #91 basename: invalid option -- 's'
  + b93d0a1.patch
    Spelling fixes and sentence structure improvements
  + fb4d8d8.patch
    Fix comment indicating the end of the function verify_file()
  + b75faa4.patch
    Convert README and COPYING into markdown files
- Rename openSUSE specific patch easyrsa.packaging.patch to
  easy-rsa-packaging.patch
- spec-cleaner -m (Add also SUSE copyrights)
* Sat Jan  2 2016 projects@localside.net
- update to version 3.0.1
  * cab4a07 Fix typo: Hellman
    (ljani: Github)
  * 171834d Fix typo: Default
    (allo-: Github)
  * 8b42eea Make aes256 default, replacing 3des
    (keros: Github)
  * f2f4ac8 Make -utf8 default
    (roubert: Github)
* Sun Apr  5 2015 projects@localside.net
- initial upload: 3.0.0-rc2 (2014/07/27)
